@@ -23,8 +23,10 @@ from .key.awaiting import AwaitingKey
 
 from .settings import BucketSettings, KeySettings, DownloadSettings
 
+from .decorators import authorize_required
 
-__version__ = "0.0.3"
+
+__version__ = "0.0.5"
 __url__ = "https://backblaze.readthedocs.io/en/latest/"
 __description__ = "Wrapper for Backblaze's B2."
 __author__ = "WardPearce"
@@ -50,17 +52,19 @@ class Awaiting(Base, AwaitingHTTP):
 
         await self._client.aclose()
 
-    async def download_by_name(self, settings: DownloadSettings,
-                               bucket_name: str, file_name: str) -> bytes:
+    @authorize_required
+    async def download_by_name(self, bucket_name: str, file_name: str,
+                               settings: DownloadSettings = None) -> bytes:
         """Used to download a file by its name.
 
         Parameters
         ----------
-        settings : DownloadSettings
         bucket_name : str
             Name of bucket.
         file_name : str
             Name of file to download.
+        settings : DownloadSettings, optional
+            by default None
 
         Returns
         -------
@@ -90,6 +94,7 @@ class Awaiting(Base, AwaitingHTTP):
             include_account=False
         )
 
+    @authorize_required
     async def create_key(self, settings: KeySettings
                          ) -> typing.Tuple[KeyModel, AwaitingKey]:
         """Used to create a key.
@@ -113,6 +118,7 @@ class Awaiting(Base, AwaitingHTTP):
 
         return KeyModel(data), self.key(data["applicationKeyId"])
 
+    @authorize_required
     async def keys(self, limit: int = 100,
                    start_key_id: str = None
                    ) -> typing.AsyncGenerator[typing.Any, None]:
@@ -158,6 +164,7 @@ class Awaiting(Base, AwaitingHTTP):
 
         return AwaitingKey(self, key_id)
 
+    @authorize_required
     async def create_bucket(self, settings: BucketSettings
                             ) -> typing.Tuple[BucketModel, AwaitingBucket]:
         """Used to create a bucket.
@@ -182,6 +189,7 @@ class Awaiting(Base, AwaitingHTTP):
 
         return data, self.bucket(data.bucket_id)
 
+    @authorize_required
     async def buckets(self, types: list = ["all"]
                       ) -> typing.AsyncGenerator[BucketModel, AwaitingBucket]:
         """Lists buckets.
@@ -277,17 +285,19 @@ class Blocking(Base, BlockingHTTP):
 
         self._client.close()
 
-    def download_by_name(self, settings: DownloadSettings,
-                         bucket_name: str, file_name: str) -> bytes:
+    @authorize_required
+    def download_by_name(self, bucket_name: str, file_name: str,
+                         settings: DownloadSettings = None) -> bytes:
         """Used to download a file by its name.
 
         Parameters
         ----------
-        settings : DownloadSettings
         bucket_name : str
             Name of bucket.
         file_name : str
             Name of file to download.
+        settings : DownloadSettings, optional
+            by default None
 
         Returns
         -------
@@ -317,6 +327,7 @@ class Blocking(Base, BlockingHTTP):
             include_account=False
         )
 
+    @authorize_required
     def create_key(self, settings: KeySettings
                    ) -> typing.Tuple[KeyModel, BlockingKey]:
         """Used to create a key.
@@ -340,9 +351,10 @@ class Blocking(Base, BlockingHTTP):
 
         return KeyModel(data), self.key(data["applicationKeyId"])
 
+    @authorize_required
     def keys(self, limit: int = 100,
              start_key_id: str = None
-             ) -> typing.AsyncGenerator[KeyModel, AwaitingKey]:
+             ) -> typing.Generator[KeyModel, AwaitingKey, None]:
         """Used to list keys.
 
         Parameters
@@ -382,6 +394,7 @@ class Blocking(Base, BlockingHTTP):
 
         return BlockingKey(self, key_id)
 
+    @authorize_required
     def create_bucket(self, settings: BucketSettings
                       ) -> typing.Tuple[BucketModel, BlockingBucket]:
         """Used to create a bucket.
@@ -406,6 +419,7 @@ class Blocking(Base, BlockingHTTP):
 
         return data, self.bucket(data.bucket_id)
 
+    @authorize_required
     def buckets(self, types: list = ["all"]
                 ) -> typing.Generator[BucketModel, BlockingBucket, None]:
         """Lists buckets.
